from setuptools import setup

setup(name='havij',
      version='0.4',
      description='The Havijest in the world',
      url='http://github.com/havij',
      author='EmAm',
      author_email='example@example.com',
      license='MIT',
      packages=['havij'],
      zip_safe=False)